Module: LesliAudit

Defined in:
app/services/lesli_audit/log_service.rb,
lib/lesli_audit.rb,
lib/lesli_audit/engine.rb,
lib/lesli_audit/version.rb,
app/models/lesli_audit/account.rb,
app/models/lesli_audit/user_log.rb,
app/models/lesli_audit/dashboard.rb,
app/models/lesli_audit/account_log.rb,
app/helpers/lesli_audit/logs_helper.rb,
app/models/lesli_audit/user_journal.rb,
app/models/lesli_audit/user_request.rb,
app/helpers/lesli_audit/users_helper.rb,
app/jobs/lesli_audit/application_job.rb,
app/models/lesli_audit/account_device.rb,
app/services/lesli_audit/user_service.rb,
app/models/lesli_audit/account_request.rb,
app/helpers/lesli_audit/accounts_helper.rb,
app/helpers/lesli_audit/requests_helper.rb,
app/services/lesli_audit/request_service.rb,
app/services/lesli_audit/visitor_service.rb,
app/helpers/lesli_audit/dashboards_helper.rb,
app/models/lesli_audit/application_record.rb,
app/helpers/lesli_audit/application_helper.rb,
app/mailers/lesli_audit/application_mailer.rb,
app/controllers/lesli_audit/logs_controller.rb,
app/interfaces/lesli_audit/logger_interface.rb,
app/controllers/lesli_audit/users_controller.rb,
app/helpers/lesli_audit/user_journals_helper.rb,
app/controllers/lesli_audit/accounts_controller.rb,
app/controllers/lesli_audit/requests_controller.rb,
app/controllers/lesli_audit/visitors_controller.rb,
app/controllers/lesli_audit/dashboards_controller.rb,
app/controllers/lesli_audit/application_controller.rb

Overview

Lesli

Copyright © 2023, Lesli Technologies, S. A.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see www.gnu.org/licenses/.

Lesli · Ruby on Rails SaaS Development Framework.

Made with ♥ by www.lesli.tech Building a better future, one line of code at a time.

// · ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ // ·

Defined Under Namespace

Modules: AccountsHelper, ApplicationHelper, DashboardsHelper, LoggerInterface, LogsHelper, RequestsHelper, UserJournalsHelper, UsersHelper Classes: Account, AccountDevice, AccountLog, AccountRequest, AccountsController, ApplicationController, ApplicationJob, ApplicationMailer, ApplicationRecord, Dashboard, DashboardsController, Engine, LogService, LogsController, RequestService, RequestsController, UserJournal, UserLog, UserRequest, UserService, UsersController, VisitorService, VisitorsController

Constant Summary collapse

VERSION =
"1.1.0"
BUILD =
"1778638613"